@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ class FollowUpReminderInfoDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit FollowUpReminderInfoDialog(QWidget *parent = Q_NULLPTR);
+    explicit FollowUpReminderInfoDialog(QWidget *parent = nullptr);
     ~FollowUpReminderInfoDialog();
 
     void load();
