@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -159,7 +159,7 @@ void FollowUpReminderManager::answerReceived(const QString &from)
     KNotification::event(QStringLiteral("mailreceived"),
                          i18n("Answer from %1 received", from),
                          pixmap,
-                         Q_NULLPTR,
+                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_followupreminder_agent"));
 
