@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,6 +27,7 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include "MailCommon/TagWidget"
 #include "MailCommon/Tag"
 #include "kmkernel.h"
+#include "helper_p.h"
 #include "util.h"
 #include "MailCommon/FolderTreeWidget"
 
@@ -61,7 +62,6 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <KMessageBox>
 #include <KKeySequenceWidget>
 #include <KLineEdit>
-#include <QDialog>
 #include <QIcon>
 #include "kmail_debug.h"
 
@@ -203,8 +203,8 @@ AppearancePageFontsTab::AppearancePageFontsTab(QWidget *parent)
     connect(mCustomFontCheck, &QAbstractButton::toggled,
             mFontChooser, &QWidget::setEnabled);
     // load the right font settings into mFontChooser:
-    connect(mFontLocationCombo, SIGNAL(activated(int)),
-            this, SLOT(slotFontSelectorChanged(int)));
+    connect(mFontLocationCombo, QOverload<int>::of(&KComboBox::activated),
+            this, &AppearancePage::FontsTab::slotFontSelectorChanged);
 }
 
 void AppearancePage::FontsTab::slotFontSelectorChanged(int index)
@@ -601,7 +601,7 @@ static const int numDateDisplayConfig =
 
 AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
     : ConfigModuleTab(parent),
-      mCustomDateFormatEdit(Q_NULLPTR)
+      mCustomDateFormatEdit(nullptr)
 {
     QVBoxLayout *vlay = new QVBoxLayout(this);
 
@@ -921,12 +921,12 @@ QString AppearancePage::MessageTagTab::helpAnchor() const
 }
 
 TagListWidgetItem::TagListWidgetItem(QListWidget *parent)
-    : QListWidgetItem(parent), mTag(Q_NULLPTR)
+    : QListWidgetItem(parent), mTag(nullptr)
 {
 }
 
 TagListWidgetItem::TagListWidgetItem(const QIcon &icon, const QString &text, QListWidget *parent)
-    : QListWidgetItem(icon, text, parent), mTag(Q_NULLPTR)
+    : QListWidgetItem(icon, text, parent), mTag(nullptr)
 {
 }
 
@@ -1319,14 +1319,14 @@ void AppearancePage::MessageTagTab::slotTagsFetched(KJob *job)
     QList<MailCommon::TagPtr> msgTagList;
     const Akonadi::Tag::List tagList = fetchJob->tags();
     msgTagList.reserve(tagList.count());
-    foreach (const Akonadi::Tag &akonadiTag, tagList) {
+    for (const Akonadi::Tag &akonadiTag : tagList) {
         MailCommon::Tag::Ptr tag = MailCommon::Tag::fromAkonadi(akonadiTag);
         msgTagList.append(tag);
     }
 
     std::sort(msgTagList.begin(), msgTagList.end(), MailCommon::Tag::compare);
 
-    foreach (const MailCommon::Tag::Ptr &tag, msgTagList) {
+    for (const MailCommon::Tag::Ptr &tag : qAsConst(msgTagList)) {
         TagListWidgetItem *newItem = new TagListWidgetItem(QIcon::fromTheme(tag->iconName), tag->tagName, mTagListBox);
         newItem->setKMailTag(tag);
         if (tag->priority == -1) {
@@ -1347,7 +1347,7 @@ void AppearancePage::MessageTagTab::slotTagsFetched(KJob *job)
 
     // Save the original list
     mOriginalMsgTagList.clear();
-    foreach (const MailCommon::TagPtr &tag, msgTagList) {
+    for (const MailCommon::TagPtr &tag : qAsConst(msgTagList)) {
         mOriginalMsgTagList.append(MailCommon::TagPtr(new MailCommon::Tag(*tag)));
     }
 
