@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,15 +21,16 @@
 #include "messagecomposer/plugineditormanager.h"
 #include "messagecomposer/plugineditor.h"
 #include "kmail_debug.h"
+#include "helper_p.h"
 
 #include <QAction>
 #include <QVector>
 
 KMailPluginEditorManagerInterface::KMailPluginEditorManagerInterface(QObject *parent)
     : QObject(parent),
-      mRichTextEditor(Q_NULLPTR),
-      mParentWidget(Q_NULLPTR),
-      mActionCollection(Q_NULLPTR)
+      mRichTextEditor(nullptr),
+      mParentWidget(nullptr),
+      mActionCollection(nullptr)
 {
 
 }
@@ -70,7 +71,7 @@ void KMailPluginEditorManagerInterface::initializePlugins()
         return;
     }
     const QVector<MessageComposer::PluginEditor *> lstPlugin = MessageComposer::PluginEditorManager::self()->pluginsList();
-    Q_FOREACH (MessageComposer::PluginEditor *plugin, lstPlugin) {
+    for (MessageComposer::PluginEditor *plugin : lstPlugin) {
         if (plugin->isEnabled()) {
             MessageComposer::PluginEditorInterface *interface = static_cast<MessageComposer::PluginEditorInterface *>(plugin->createInterface(mActionCollection, this));
             interface->setRichTextEditor(mRichTextEditor);
@@ -105,11 +106,11 @@ QList<QAction *> KMailPluginEditorManagerInterface::actionsType(MessageComposer:
 QHash<MessageComposer::ActionType::Type, QList<QAction *> > KMailPluginEditorManagerInterface::actionsType()
 {
     if (mActionHash.isEmpty()) {
-        Q_FOREACH (MessageComposer::PluginEditorInterface *interface, mListPluginInterface) {
+        for (MessageComposer::PluginEditorInterface *interface : qAsConst(mListPluginInterface)) {
             MessageComposer::ActionType actionType = interface->actionType();
             MessageComposer::ActionType::Type type = actionType.type();
-            if (mActionHash.contains(type)) {
-                QList<QAction *> lst = mActionHash.value(type);
+            QList<QAction *> lst = mActionHash.value(type);
+            if (!lst.isEmpty()) {
                 QAction *act = new QAction(this);
                 act->setSeparator(true);
                 lst << act << actionType.action();
@@ -119,8 +120,8 @@ QHash<MessageComposer::ActionType::Type, QList<QAction *> > KMailPluginEditorMan
             }
             if (interface->plugin()->hasPopupMenuSupport()) {
                 type = MessageComposer::ActionType::PopupMenu;
-                if (mActionHash.contains(type)) {
-                    QList<QAction *> lst = mActionHash.value(type);
+                QList<QAction *> lst = mActionHash.value(type);
+                if (!lst.isEmpty()) {
                     QAction *act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
@@ -131,8 +132,8 @@ QHash<MessageComposer::ActionType::Type, QList<QAction *> > KMailPluginEditorMan
             }
             if (interface->plugin()->hasToolBarSupport()) {
                 type = MessageComposer::ActionType::ToolBar;
-                if (mActionHash.contains(type)) {
-                    QList<QAction *> lst = mActionHash.value(type);
+                QList<QAction *> lst = mActionHash.value(type);
+                if (!lst.isEmpty()) {
                     QAction *act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
